This crate houses the s! macro, used to create Symbol / CustomSymbol instances at
const-eval time from a provided ident and (if applicable) Alphabet.
Macros
- custom_
alphabet - Allows you to define a custom alphabet for use with
CustomSymboland thes!macro. The macro takes two idents separated by a comma as input. The first ident should be the name of the alphabet you would like to create, and the second ident should contain all of the characters you would like to use in your alphabet (symbols must be comprised only of characters that are valid in an ident. - s
- Generates a
SymbolorCustomSymbolat const-eval time based on the provided ident and (optional) path to a customAlphabet., e.g.: